================
chatterbot-voice
================

This is a text to speech (tts) and speech recognition adapter
designed to use with ChatterBot_.

Speech recognition
------------------

The speech recognition used in this module is done using
Anthony Zhang's SpeechRecognition_ library for Python.

Speech synthesis
----------------

Speech synthesis in this project is done using espeak.
Note: For Mac users, the adapter will use Mac's built-in
say command.

Installation
------------

pip install chatterbot-voice

Examples
--------

See the examples_ directory in the GitHub repo.


.. _ChatterBot: https://github.com/gunthercox/ChatterBot
.. _SpeechRecognition: https://github.com/Uberi/speech_recognition
.. _examples: https://github.com/gunthercox/chatterbot-voice/tree/master/examples
